@@ -18,7 +18,8 @@ import os
 
 import pytest
 
-from platformio import __core_packages__, fs
+from platformio import fs
+from platformio.dependencies import get_core_dependencies
 from platformio.package.commands.install import package_install_cmd
 from platformio.package.manager.library import LibraryPackageManager
 from platformio.package.manager.platform import PlatformPackageManager
@@ -30,7 +31,7 @@ PROJECT_CONFIG_TPL = """
 [env]
 platform = platformio/atmelavr@^3.4.0
 lib_deps =
-    milesburton/DallasTemperature@^3.9.1
+    milesburton/DallasTemperature@^4.0.4
     https://github.com/esphome/ESPAsyncWebServer/archive/refs/tags/v2.1.0.zip
 
 [env:baremetal]
@@ -177,7 +178,7 @@ def test_baremetal_project(
             ),
         ]
         assert pkgs_to_specs(ToolPackageManager().get_installed()) == [
-            PackageSpec("tool-scons@%s" % __core_packages__["tool-scons"][1:]),
+            PackageSpec("tool-scons@%s" % get_core_dependencies()["tool-scons"][1:]),
             PackageSpec("toolchain-atmelavr@1.70300.191015"),
         ]
 
@@ -210,11 +211,11 @@ def test_project(
         ]
         assert pkgs_to_specs(ToolPackageManager().get_installed()) == [
             PackageSpec("framework-arduino-avr-attiny@1.5.2"),
-            PackageSpec("tool-scons@%s" % __core_packages__["tool-scons"][1:]),
+            PackageSpec("tool-scons@%s" % get_core_dependencies()["tool-scons"][1:]),
             PackageSpec("toolchain-atmelavr@1.70300.191015"),
         ]
         assert config.get("env:devkit", "lib_deps") == [
-            "milesburton/DallasTemperature@^3.9.1",
+            "milesburton/DallasTemperature@^4.0.4",
             "https://github.com/esphome/ESPAsyncWebServer/archive/refs/tags/v2.1.0.zip",
         ]
 
@@ -233,24 +234,20 @@ def test_private_lib_deps(
     project_dir = tmp_path / "project"
     private_lib_dir = project_dir / "lib" / "private"
     private_lib_dir.mkdir(parents=True)
-    (private_lib_dir / "library.json").write_text(
-        """
+    (private_lib_dir / "library.json").write_text("""
 {
     "name": "My Private Lib",
     "version": "1.0.0",
     "dependencies": {
         "bblanchon/ArduinoJson": "^5",
-        "milesburton/DallasTemperature": "^3.9.1"
+        "milesburton/DallasTemperature": "^4.0.4"
     }
 }
-"""
-    )
-    (project_dir / "platformio.ini").write_text(
-        """
+""")
+    (project_dir / "platformio.ini").write_text("""
 [env:private]
 platform = native
-"""
-    )
+""")
     with fs.cd(str(project_dir)):
         config = ProjectConfig()
 
@@ -339,7 +336,7 @@ def test_remove_project_unused_libdeps(
             ),
         ]
 
-        # manually remove from cofiguration file
+        # manually remove from configuration file
         config.set("env:baremetal", "lib_deps", ["bblanchon/ArduinoJson@^5"])
         config.save()
         result = clirunner.invoke(
@@ -356,15 +353,13 @@ def test_unknown_project_dependencies(
 ):
     project_dir = tmp_path / "project"
     project_dir.mkdir()
-    (project_dir / "platformio.ini").write_text(
-        """
+    (project_dir / "platformio.ini").write_text("""
 [env:unknown_platform]
 platform = unknown_platform
 
 [env:unknown_lib_deps]
 lib_deps = SPI, platformio/unknown_library
-"""
-    )
+""")
     with fs.cd(str(project_dir)):
         result = clirunner.invoke(
             package_install_cmd,
@@ -445,7 +440,7 @@ def test_custom_project_libraries(
         )
         assert pkgs_to_specs(lm.get_installed()) == [
             PackageSpec("ArduinoJson@5.13.4"),
-            PackageSpec("Nanopb@0.4.7"),
+            PackageSpec("Nanopb@0.4.91"),
         ]
         assert config.get("env:devkit", "lib_deps") == [
             "bblanchon/ArduinoJson@^5",
