@@ -95,15 +95,13 @@ def test_build_legacy_spec(isolated_pio_core, tmpdir_factory):
     pm = PlatformPackageManager(str(storage_dir))
     # test src manifest
     pkg1_dir = storage_dir.join("pkg-1").mkdir()
-    pkg1_dir.join(".pio").mkdir().join(".piopkgmanager.json").write(
-        """
+    pkg1_dir.join(".pio").mkdir().join(".piopkgmanager.json").write("""
 {
     "name": "StreamSpy-0.0.1.tar",
     "url": "https://dl.platformio.org/e8936b7/StreamSpy-0.0.1.tar.gz",
     "requirements": null
 }
-"""
-    )
+""")
     assert pm.build_legacy_spec(str(pkg1_dir)) == PackageSpec(
         name="StreamSpy-0.0.1.tar",
         uri="https://dl.platformio.org/e8936b7/StreamSpy-0.0.1.tar.gz",
@@ -181,12 +179,10 @@ def test_install_from_uri(isolated_pio_core, tmpdir_factory):
 
     # install from registry
     src_dir = tmp_dir.join("registry-1").mkdir()
-    src_dir.join("library.properties").write(
-        """
+    src_dir.join("library.properties").write("""
 name = wifilib
 version = 5.2.7
-"""
-    )
+""")
     spec = PackageSpec("company/wifilib @ ^5")
     pkg = lm.install_from_uri("file://%s" % src_dir, spec)
     assert str(pkg.metadata.version) == "5.2.7"
@@ -219,7 +215,7 @@ def test_install_from_registry(isolated_pio_core, tmpdir_factory):
     # test conflicted names
     lm = LibraryPackageManager(str(tmpdir_factory.mktemp("conflicted-storage")))
     lm.set_log_level(logging.ERROR)
-    lm.install("z3t0/IRremote@2.6.1")
+    lm.install("z3t0/IRremote")
     lm.install("mbed-yuhki50/IRremote")
     assert len(lm.get_installed()) == 2
 
@@ -244,8 +240,7 @@ def test_install_lib_depndencies(isolated_pio_core, tmpdir_factory):
     src_dir = tmp_dir.join("lib-with-deps").mkdir()
     root_dir = src_dir.mkdir("root")
     root_dir.mkdir("src").join("main.cpp").write("#include <stdio.h>")
-    root_dir.join("library.json").write(
-        """
+    root_dir.join("library.json").write("""
 {
   "name": "lib-with-deps",
   "version": "2.0.0",
@@ -261,8 +256,7 @@ def test_install_lib_depndencies(isolated_pio_core, tmpdir_factory):
     }
   ]
 }
-"""
-    )
+""")
 
     lm = LibraryPackageManager(str(tmpdir_factory.mktemp("lib-storage")))
     lm.set_log_level(logging.ERROR)
@@ -293,26 +287,22 @@ def test_install_force(isolated_pio_core, tmpdir_factory):
 def test_symlink(tmp_path: Path):
     external_pkg_dir = tmp_path / "External"
     external_pkg_dir.mkdir()
-    (external_pkg_dir / "library.json").write_text(
-        """
+    (external_pkg_dir / "library.json").write_text("""
 {
     "name": "External",
     "version": "1.0.0"
 }
-"""
-    )
+""")
 
     storage_dir = tmp_path / "storage"
     installed_pkg_dir = storage_dir / "installed"
     installed_pkg_dir.mkdir(parents=True)
-    (installed_pkg_dir / "library.json").write_text(
-        """
+    (installed_pkg_dir / "library.json").write_text("""
 {
     "name": "Installed",
     "version": "1.0.0"
 }
-"""
-    )
+""")
 
     spec = "CustomExternal=symlink://%s" % str(external_pkg_dir)
     lm = LibraryPackageManager(str(storage_dir))
@@ -335,7 +325,7 @@ def test_symlink(tmp_path: Path):
     # uninstall
     lm.uninstall("External")
     assert ["Installed"] == [pkg.metadata.name for pkg in lm.get_installed()]
-    # ensure original package was not rmeoved
+    # ensure original package was not removed
     assert external_pkg_dir.is_dir()
 
     # install again, remove from a disk
@@ -353,8 +343,7 @@ def test_scripts(isolated_pio_core, tmp_path: Path):
     pkg_dir = tmp_path / "foo"
     scripts_dir = pkg_dir / "scripts"
     scripts_dir.mkdir(parents=True)
-    (scripts_dir / "script.py").write_text(
-        """
+    (scripts_dir / "script.py").write_text("""
 import sys
 from pathlib import Path
 
@@ -363,10 +352,8 @@ Path("%s.flag" % action).touch()
 
 if action == "preuninstall":
     Path("../%s.flag" % action).touch()
-"""
-    )
-    (pkg_dir / "library.json").write_text(
-        """
+""")
+    (pkg_dir / "library.json").write_text("""
 {
     "name": "foo",
     "version": "1.0.0",
@@ -375,8 +362,7 @@ if action == "preuninstall":
         "preuninstall2": ["scripts/script.py", "preuninstall"]
     }
 }
-"""
-    )
+""")
 
     storage_dir = tmp_path / "storage"
     lm = LibraryPackageManager(str(storage_dir))
@@ -392,8 +378,7 @@ def test_install_circular_dependencies(tmp_path: Path):
     # Foo
     pkg_dir = storage_dir / "foo"
     pkg_dir.mkdir(parents=True)
-    (pkg_dir / "library.json").write_text(
-        """
+    (pkg_dir / "library.json").write_text("""
 {
     "name": "Foo",
     "version": "1.0.0",
@@ -401,13 +386,11 @@ def test_install_circular_dependencies(tmp_path: Path):
         "Bar": "*"
     }
 }
-"""
-    )
+""")
     # Bar
     pkg_dir = storage_dir / "bar"
     pkg_dir.mkdir(parents=True)
-    (pkg_dir / "library.json").write_text(
-        """
+    (pkg_dir / "library.json").write_text("""
 {
     "name": "Bar",
     "version": "1.0.0",
@@ -415,8 +398,7 @@ def test_install_circular_dependencies(tmp_path: Path):
         "Foo": "*"
     }
 }
-"""
-    )
+""")
 
     lm = LibraryPackageManager(str(storage_dir))
     lm.set_log_level(logging.ERROR)
@@ -425,8 +407,7 @@ def test_install_circular_dependencies(tmp_path: Path):
     # root library
     pkg_dir = tmp_path / "root"
     pkg_dir.mkdir(parents=True)
-    (pkg_dir / "library.json").write_text(
-        """
+    (pkg_dir / "library.json").write_text("""
 {
     "name": "Root",
     "version": "1.0.0",
@@ -435,8 +416,7 @@ def test_install_circular_dependencies(tmp_path: Path):
         "Bar": "^1.0.0"
     }
 }
-"""
-    )
+""")
     lm.install("file://%s" % str(pkg_dir))
 
 
@@ -445,14 +425,7 @@ def test_get_installed(isolated_pio_core, tmpdir_factory):
     pm = ToolPackageManager(str(storage_dir))
 
     # VCS package
-    (
-        storage_dir.join("pkg-vcs")
-        .mkdir()
-        .join(".git")
-        .mkdir()
-        .join(".piopm")
-        .write(
-            """
+    (storage_dir.join("pkg-vcs").mkdir().join(".git").mkdir().join(".piopm").write("""
 {
   "name": "pkg-via-vcs",
   "spec": {
@@ -465,9 +438,7 @@ def test_get_installed(isolated_pio_core, tmpdir_factory):
   "type": "tool",
   "version": "0.0.0+sha.1ea4d5e"
 }
-"""
-        )
-    )
+"""))
 
     # package without metadata file
     (
@@ -480,8 +451,7 @@ def test_get_installed(isolated_pio_core, tmpdir_factory):
     # package with metadata file
     foo_dir = storage_dir.join("foo").mkdir()
     foo_dir.join("package.json").write('{"name": "foo", "version": "3.6.0"}')
-    foo_dir.join(".piopm").write(
-        """
+    foo_dir.join(".piopm").write("""
 {
   "name": "foo",
   "spec": {
@@ -492,8 +462,7 @@ def test_get_installed(isolated_pio_core, tmpdir_factory):
   "type": "tool",
   "version": "3.6.0"
 }
-"""
-    )
+""")
 
     # test "system"
     storage_dir.join("pkg-incompatible-system").mkdir().join("package.json").write(
@@ -554,14 +523,14 @@ def test_uninstall(isolated_pio_core, tmpdir_factory):
     assert not lm.get_installed()
 
     # test uninstall dependencies
-    assert lm.install("AsyncMqttClient-esphome @ 0.8.4")
+    assert lm.install("AsyncMqttClient-esphome")
     assert len(lm.get_installed()) == 3
     assert lm.uninstall("AsyncMqttClient-esphome", skip_dependencies=True)
     assert len(lm.get_installed()) == 2
 
     lm = LibraryPackageManager(str(storage_dir))
     lm.set_log_level(logging.ERROR)
-    assert lm.install("AsyncMqttClient-esphome @ 0.8.4")
+    assert lm.install("AsyncMqttClient-esphome")
     assert lm.uninstall("AsyncMqttClient-esphome")
     assert not lm.get_installed()
 
@@ -604,23 +573,23 @@ def test_update_with_metadata(isolated_pio_core, tmpdir_factory):
     assert str(outdated.current) == "1.8.7"
     assert outdated.latest > semantic_version.Version("1.10.0")
 
-    pkg = lm.install("ArduinoJson @ 5.10.1")
+    pkg = lm.install("ArduinoJson @ 6.19.4")
     # test latest
     outdated = lm.outdated(pkg)
-    assert str(outdated.current) == "5.10.1"
+    assert str(outdated.current) == "6.19.4"
     assert outdated.wanted is None
     assert outdated.latest > outdated.current
     assert outdated.latest > semantic_version.Version("5.99.99")
 
     # test wanted
-    outdated = lm.outdated(pkg, PackageSpec("ArduinoJson@~5"))
-    assert str(outdated.current) == "5.10.1"
-    assert str(outdated.wanted) == "5.13.4"
+    outdated = lm.outdated(pkg, PackageSpec("ArduinoJson@~6"))
+    assert str(outdated.current) == "6.19.4"
+    assert str(outdated.wanted) == "6.21.5"
     assert outdated.latest > semantic_version.Version("6.16.0")
 
-    # update to the wanted 5.x
-    new_pkg = lm.update("ArduinoJson@^5", PackageSpec("ArduinoJson@^5"))
-    assert str(new_pkg.metadata.version) == "5.13.4"
+    # update to the wanted 6.x
+    new_pkg = lm.update("ArduinoJson@^6", PackageSpec("ArduinoJson@^6"))
+    assert str(new_pkg.metadata.version) == "6.21.5"
     # check that old version is removed
     assert len(lm.get_installed()) == 2
 
@@ -651,4 +620,4 @@ def test_update_without_metadata(isolated_pio_core, tmpdir_factory):
     lm.set_log_level(logging.ERROR)
     new_pkg = lm.update(pkg)
     assert len(lm.get_installed()) == 4
-    assert new_pkg.metadata.spec.owner == "ottowinter"
+    assert new_pkg.metadata.spec.owner == "heman"
